"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }// src/plugin/index.ts
var _path = require('path');
var _tsmockgenerator = require('ts-mock-generator');

// src/utils/log.ts
var _chalk = require('chalk'); var _chalk2 = _interopRequireDefault(_chalk);
var colorful = (flag) => {
  switch (flag) {
    case LOG_FLAG.INFO:
      return _chalk2.default.greenBright;
    case LOG_FLAG.WARNING:
      return _chalk2.default.yellowBright;
    case LOG_FLAG.ERROR:
      return _chalk2.default.redBright;
  }
};
var LOG_FLAG;
(function(LOG_FLAG2) {
  LOG_FLAG2["INFO"] = "info";
  LOG_FLAG2["WARNING"] = "warning";
  LOG_FLAG2["ERROR"] = "error";
})(LOG_FLAG || (LOG_FLAG = {}));
var Logger = class {
  constructor(prefix) {
    this.prefix = prefix;
  }
  info(msg) {
    this.log(LOG_FLAG.INFO, msg);
  }
  warning(msg) {
    this.log(LOG_FLAG.WARNING, msg);
  }
  error(msg) {
    this.log(LOG_FLAG.ERROR, msg);
  }
  log(flag, msg) {
    console.log(colorful(flag)(`[${this.prefix}:${flag}]`), msg);
  }
};
var logger = new Logger("vite-plugin-faker");

// src/plugin/index.ts
var mockData;
var getOrGenerateMockData = async (opts) => {
  const mockDataResolver = new (0, _tsmockgenerator.MockDataResolver)({
    configPath: _path.join.call(void 0, process.cwd(), "tsconfig.json"),
    basePath: _path.join.call(void 0, process.cwd(), opts.basePath),
    mockDir: opts.mockDir ? _path.join.call(void 0, process.cwd(), opts.mockDir) : void 0,
    includes: opts.includes || []
  });
  mockData = mockDataResolver.getOrGenerateData();
  if (opts.watchFile) {
    mockDataResolver.watchMockFile((data) => {
      mockData = data;
    });
    mockDataResolver.watchRequestFile((data) => {
      mockData = data;
    });
  }
};
var getTargetMockData = (url) => mockData.filter((data) => data.url === url);
var sleep = (delay) => new Promise((resolve) => {
  setTimeout(() => {
    resolve(null);
  }, delay);
});
var requestMiddleware = async (req, res, next) => {
  var _a;
  const url = (_a = req.url) == null ? void 0 : _a.split("?")[0];
  const targetMockData = getTargetMockData(url);
  if (targetMockData.length > 0) {
    logger.info(`invoke mock proxy: ${url}`);
    const data = targetMockData[0];
    if (data.timeout) {
      await sleep(data.timeout);
    }
    res.setHeader("Content-Type", "application/json");
    res.statusCode = data.httpCode ? data.httpCode : 200;
    res.end(JSON.stringify(data.response));
    return;
  }
  next();
};

// src/index.ts
var vitePluginFaker = (opts) => {
  return {
    name: "vite-faker",
    configureServer({middlewares}) {
      getOrGenerateMockData(opts);
      middlewares.use(requestMiddleware);
    }
  };
};


exports.vitePluginFaker = vitePluginFaker;
